(**************************************************************)
(*
 *  Ensemble, (Version 0.70p1)
 *  Copyright 2000 Cornell University
 *  All rights reserved.
 *
 *  See ensemble/doc/license.txt for further information.
 *)
(**************************************************************)
(**************************************************************)
(* HTK.MLI *)
(* Author: Mark Hayden, 3/96 *)
(**************************************************************)

val init : Alarm.t -> unit
